@@ -42,6 +42,13 @@
 #define AVCODEC_MAX_AUDIO_FRAME_SIZE 192000
 #endif
 
+#ifndef HAVE_AV_FRAME_ALLOC
+#define av_frame_alloc avcodec_alloc_frame
+#endif
+#ifndef HAVE_AV_FRAME_UNREF
+#define av_frame_unref avcodec_get_frame_defaults
+#endif
+
 extern int dynamic_metadata_form[];
 
 static const struct timespec time_delay = { .tv_nsec = 10 };
@@ -173,13 +180,13 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
         
         if (!self->frame)
             {
-            if (!(self->frame = avcodec_alloc_frame()))
+            if (!(self->frame = av_frame_alloc()))
                 {
                 fprintf(stderr, "avcodecdecode_play: malloc failure\n");
                 exit(1);
                 }
             else
-                avcodec_get_frame_defaults(self->frame);
+                av_frame_unref(self->frame);
             }
 
         while (pthread_mutex_trylock(&g.avc_mutex))
@@ -245,7 +252,7 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
         if (self->floatsamples)
             av_freep(&self->floatsamples);
 
-        if (av_samples_alloc(&self->floatsamples, NULL, 2, self->frame->nb_samples, AV_SAMPLE_FMT_FLT, 0))
+        if (av_samples_alloc(&self->floatsamples, NULL, 2, self->frame->nb_samples, AV_SAMPLE_FMT_FLT, 0) < 0)
             {
             fprintf(stderr, "avcodecdecode_play: av_samples_alloc failed\n");
             xlplayer->playmode = PM_EJECTING;
