@@ -19,26 +19,26 @@
 
 #include "../config.h"
 
-#ifdef DYN_LAME
-#include "lame.h"
-#else
+#ifdef HAVE_LAME_LAME_H
 #include <lame/lame.h>
-#endif /* DYN_LAME */
+#else 
+#include "lame.h"
+#endif /* HAVE_LAME_LAME_H */
+
 #include "sourceclient.h"
 
-struct lme_data
-   {
-   lame_global_flags *gfp;
-   int lame_mode;
-   int lame_channels;
-   int lame_quality;
-   int lame_freeformat;
-   char *metadata;
-   int lame_samples;
-   unsigned char *mp3buf;
-   size_t mp3bufsize;
-   enum packet_flags packetflags;
-   };
+struct lm3e_data
+    {
+    lame_global_flags *gfp;
+    int lame_mode;
+    int lame_channels;
+    int lame_quality;
+    char *metadata;
+    int lame_samples;
+    unsigned char *mp3buf;
+    size_t mp3bufsize;
+    enum packet_flags packetflags;
+    };
 
 int live_mp3_encoder_init(struct encoder *encoder, struct encoder_vars *ev);
 
