@@ -29,17 +29,10 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#ifdef HAVE_AVCODEC
-#ifdef HAVE_AVFORMAT
-#ifdef FFMPEG_AVCODEC
-#include <ffmpeg/avcodec.h>
-#include <ffmpeg/avformat.h>
-#else
+#ifdef HAVE_LIBAV
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
-#endif /* FFMPEG_AVCODEC */
-#endif /* HAVE_AVFORMAT */
-#endif /* HAVE_AVCODEC */
+#endif /* HAVE_LIBAV */
 
 #include "sig.h"
 #include "mixer.h"
@@ -179,8 +172,7 @@ static int backend_main()
         exit(5);
         }
 
-#ifdef HAVE_AVCODEC
-#ifdef HAVE_AVFORMAT
+#ifdef HAVE_LIBAV
     if (pthread_mutex_init(&g.avc_mutex, NULL))
         {
         fprintf(stderr, "pthread_mutex_init failed\n");
@@ -188,8 +180,7 @@ static int backend_main()
         }
     avcodec_register_all();
     av_register_all();
-#endif /* HAVE_AVFORMAT */
-#endif /* HAVE_AVCODEC */
+#endif /* HAVE_LIBAV */
 
     alarm(3);
 
