@@ -44,6 +44,7 @@ static void *streamer_main(void *args)
     struct encoder_op_packet *packet;
     char buffer[10];
     size_t data_size;
+    unsigned connect_time = 0;
     
     char *s_conv(unsigned long value)
         {
@@ -70,7 +71,7 @@ static void *streamer_main(void *args)
                     case SHOUTERR_BUSY:
                         self->shout_status = shout_get_connected(self->shout);
 
-                        if (self->disconnect_request)
+                        if (self->disconnect_request || ++connect_time > 120)
                             self->stream_mode = SM_DISCONNECTING;
                         break;
                     case SHOUTERR_CONNECTED:
@@ -111,7 +112,7 @@ static void *streamer_main(void *args)
                             /* determine how much audio to hold in the send buffer */
                             self->max_shout_queue = (shout_buffer_seconds * ((br > 1000) ? br / 1000 : br)) << 7;
                             }
-                        if (packet->header.flags & (PF_OGG | PF_MP3 | PF_MP2 | PF_AAC | PF_AACP2))
+                        if (packet->header.flags & (PF_WEBM | PF_OGG | PF_MP3 | PF_MP2 | PF_AAC | PF_AACP2))
                             {
                             if ((packet->header.flags & (PF_HEADER | PF_FINAL)) || shout_queuelen(self->shout) < self->max_shout_queue)
                                 data_size = packet->header.data_size;
@@ -177,6 +178,7 @@ static void *streamer_main(void *args)
                 self->disconnect_request = FALSE;
                 self->disconnect_pending = FALSE;
                 self->stream_mode = SM_DISCONNECTED;
+                connect_time = 0;
                 fprintf(stderr, "streamer_main: disconnection complete\n");
                 break;
             }
@@ -203,7 +205,7 @@ int streamer_connect(struct threads_info *ti, struct universal_vars *uv, void *o
     {
     struct streamer_vars *sv = other;
     struct streamer *self = ti->streamer[uv->tab];
-    int protocol, data_format = -1;
+    int protocol, data_format = -1, tls;
     char channels[2];
     char bitrate[4];
     char samplerate[6];
@@ -233,6 +235,7 @@ int streamer_connect(struct threads_info *ti, struct universal_vars *uv, void *o
             case ENCODER_FAMILY_OGG:
                 data_format = SHOUT_FORMAT_OGG;
                 break;
+
             case ENCODER_FAMILY_MPEG:
                 switch (df->codec) {
                     case ENCODER_CODEC_MP3:
@@ -248,8 +251,20 @@ int streamer_connect(struct threads_info *ti, struct universal_vars *uv, void *o
                     case ENCODER_CODEC_UNHANDLED:
                     default:
                         failed = TRUE;
-                    }
-                    break;
+                }
+                break;
+                
+            case ENCODER_FAMILY_WEBM:
+                switch (df->codec) {
+                    case ENCODER_CODEC_VORBIS:
+                    case ENCODER_CODEC_OPUS:
+                        data_format = SHOUT_FORMAT_WEBMAUDIO;
+                        break;
+                    default:
+                        failed = TRUE;
+                }
+                break;
+                
             case ENCODER_FAMILY_UNHANDLED:
                 failed = TRUE;
             }
@@ -330,48 +345,83 @@ int streamer_connect(struct threads_info *ti, struct universal_vars *uv, void *o
         else
             fprintf(stderr, "user agent is set\n");
         }
-    if (shout_set_name(self->shout, sv->dj_name) != SHOUTERR_SUCCESS)
+    if (shout_set_meta(self->shout, SHOUT_META_NAME, sv->dj_name) != SHOUTERR_SUCCESS)
         {
         sce("stream/dj name");
         goto error;
         }
-    if (shout_set_url(self->shout, sv->listen_url) != SHOUTERR_SUCCESS)
+    if (shout_set_meta(self->shout, SHOUT_META_URL, sv->listen_url) != SHOUTERR_SUCCESS)
         {
         sce("url");
         goto error;
         }
-    if (shout_set_description(self->shout, sv->description) != SHOUTERR_SUCCESS)
+    if (shout_set_meta(self->shout, SHOUT_META_DESCRIPTION, sv->description) != SHOUTERR_SUCCESS)
         {
         sce("description");
         goto error;
         }
-    if (shout_set_genre(self->shout, sv->genre) != SHOUTERR_SUCCESS)
+    if (shout_set_meta(self->shout, SHOUT_META_GENRE, sv->genre) != SHOUTERR_SUCCESS)
         {
         sce("genre");
         goto error;
         }
-
-    if (shout_set_irc(self->shout, sv->irc) != SHOUTERR_SUCCESS)
+    if (shout_set_meta(self->shout, SHOUT_META_IRC, sv->irc) != SHOUTERR_SUCCESS)
         {
         sce("irc");
         goto error;
         }
-    if (shout_set_aim(self->shout, sv->aim) != SHOUTERR_SUCCESS)
+    if (shout_set_meta(self->shout, SHOUT_META_AIM, sv->aim) != SHOUTERR_SUCCESS)
         {
         sce("aim");
         goto error;
         }
-    if (shout_set_icq(self->shout, sv->icq) != SHOUTERR_SUCCESS)
+    if (shout_set_meta(self->shout, SHOUT_META_ICQ, sv->icq) != SHOUTERR_SUCCESS)
         {
         sce("icq");
         goto error;
         }
-
     if (shout_set_public(self->shout, !strcmp(sv->make_public, "True")) != SHOUTERR_SUCCESS)
         {
         sce("make public");
         goto error;
         }
+    #if SHOUT_TLS
+    if (!strcmp("Disabled", sv->tls))
+        tls = SHOUT_TLS_DISABLED;
+    else if (!strcmp("Auto", sv->tls))
+        tls = SHOUT_TLS_AUTO;
+    else if (!strcmp("Auto, no plaintext", sv->tls))
+        tls = SHOUT_TLS_AUTO_NO_PLAIN;
+    else if (!strcmp("RFC2818", sv->tls))
+        tls = SHOUT_TLS_RFC2818;
+    else if (!strcmp("RFC2817", sv->tls))
+        tls = SHOUT_TLS_RFC2817;
+    else
+        {
+        sce("tls option");
+        goto error;
+        }
+    if (shout_set_tls(self->shout, tls) != SHOUTERR_SUCCESS)
+        {
+        sce("tls");
+        goto error;
+        }
+    if (sv->ca_dir[0] && shout_set_ca_directory(self->shout, sv->ca_dir) != SHOUTERR_SUCCESS)
+        {
+        sce("ca directory");
+        goto error;
+        }
+    if (sv->ca_file[0] && shout_set_ca_file(self->shout, sv->ca_file) != SHOUTERR_SUCCESS)
+        {
+        sce("ca file");
+        goto error;
+        }
+    if (sv->client_cert[0] && shout_set_client_certificate(self->shout, sv->client_cert) != SHOUTERR_SUCCESS)
+        {
+        sce("client certificate");
+        goto error;
+        }
+    #endif
         
     snprintf(channels,   sizeof channels  , "%d",  self->encoder_op->encoder->n_channels);
     {
