@@ -39,6 +39,10 @@ struct streamer_vars
     char *irc;
     char *aim;
     char *icq;
+    char *tls;
+    char *ca_dir;
+    char *ca_file;
+    char *client_cert;
     char *make_public;
     };
 
