@@ -1,6 +1,6 @@
 /*
 #   xlplayer.c: player decoder module for idjc
-#   Copyright (C) 2006-2012 Stephen Fairchild (s-fairchild@users.sourceforge.net)
+#   Copyright (C) 2006-2013 Stephen Fairchild (s-fairchild@users.sf.net)
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -341,11 +341,9 @@ static void *xlplayer_main(struct xlplayer *self)
                           || (!strcmp(extension, "flac") && flacdecode_reg(self))
 #endif
                           || ((!strcmp(extension, "wav") || !strcmp(extension, "au") || !strcmp(extension, "aiff")) && sndfiledecode_reg(self))
-#ifdef HAVE_AVCODEC
-#ifdef HAVE_AVFORMAT
+#ifdef HAVE_LIBAV
                           || ((!strcmp(extension, "aac") || !strcmp(extension, "m4a") || !strcmp(extension, "mp4") || !strcmp(extension, "m4b") || !strcmp(extension, "m4p") || !strcmp(extension, "wma") || !strcmp(extension, "avi") || !strcmp(extension, "mpc") || !strcmp(extension, "ape")) && avcodecdecode_reg(self))
-#endif /* HAVE_AVFORMAT */
-#endif /* HAVE_AVCODEC */
+#endif /* HAVE_LIBAV */
                           || ((!strcmp(extension, "mp3") || (!strcmp(extension, "mp2"))) && mpg123ok && mp3decode_reg(self))
                     )
                     {
@@ -373,6 +371,12 @@ static void *xlplayer_main(struct xlplayer *self)
                 else
                     self->dec_play(self);
                 break;
+            case PM_FLUSH:
+                if (self->write_deferred)
+                    xlplayer_write_channel_data(self);
+                else
+                    self->playmode = PM_EJECTING;
+                break;
             case PM_EJECTING:
                 xlplayer_set_fadesteps(self, self->fade_mode);
                 self->dec_eject(self);
