@@ -26,7 +26,7 @@ import pango
 
 from idjc import FGlobs
 from idjc.prelims import ProfileManager
-from .gtkstuff import threadslock
+from .gtkstuff import threadslock, idle_add
 
 import gettext
 t = gettext.translation(FGlobs.package_name, FGlobs.localedir, fallback=True)
@@ -207,7 +207,7 @@ class ReconnectionDialog(gtk.Dialog):
             self.label2.set_text(self.lines[1].format(countdown=self.remaining))
             if self.remaining == 0:
                 self.hide()
-                glib.idle_add(self.reconnect_idle)
+                idle_add(self.reconnect_idle)
                 
     @threadslock
     def reconnect_idle(self):
