@@ -430,6 +430,7 @@ class FormatSpin(gtk.VBox):
         size_group = gtk.SizeGroup(gtk.SIZE_GROUP_VERTICAL)
         size_group.add_widget(prev_object.get_children()[0])
         size_group.add_widget(frame)
+        self.scale = 1
 
     def _on_changed(self, spin_button):
         self._fixed.set_text(str(int(spin_button.props.value)) + self._unit)
@@ -477,12 +478,20 @@ class FormatSpin(gtk.VBox):
         
     @property
     def value(self):
-        return str(int(self._spin_button.props.value))
+        return str(int(self._spin_button.props.value * self.scale))
 
     @value.setter
     def value(self, value):
         if not self.applied:
-            self._spin_button.props.value = int(value)
+            self._spin_button.props.value = int(value) // self.scale
+            
+    @property
+    def scale(self):
+        return self._scale
+
+    @scale.setter
+    def scale(self, value):
+        self._scale = value
 
 
 class FormatPregain(FormatDropdown):
@@ -525,13 +534,24 @@ class FormatMetadataChoice(FormatDropdown):
             _("This affects the stream metadata only. Recordings will use UTF-8 for their metadata."))
 
 
+class FormatMetadataNone(FormatDropdown):
+    """User can not select any metadata."""
+    
+    def __init__(self, prev_object):
+        FormatDropdown.__init__(self, prev_object, _('Metadata'), "metadata_mode", (
+            dict(display_text=_('Unsupported'), value="suppressed", chain="FormatResampleQuality"),), 1,
+            _("Choose whether the stream will carry dynamic metadata. In the case of Ogg streams this is important as a great many players can't handle chained Ogg streams which result from the metadata updates."))
+
+
 class FormatMetadataUTF8(FormatDropdown):
     """User can select whether to have metadata."""
     
     def __init__(self, prev_object):
+        discourage = format_collate(prev_object)["family"] == "webm"
+        
         FormatDropdown.__init__(self, prev_object, _('Metadata'), "metadata_mode", (
-            dict(display_text=_('Suppressed'), value="suppressed", chain="FormatResampleQuality"),
-            dict(display_text=_('UTF-8'), value="utf-8", chain="FormatResampleQuality", default=True)), 1,
+            dict(display_text=_('Suppressed'), value="suppressed", chain="FormatResampleQuality", default=discourage),
+            dict(display_text=_('UTF-8'), value="utf-8", chain="FormatResampleQuality", default=not discourage)), 1,
             _("Choose whether the stream will carry dynamic metadata. In the case of Ogg streams this is important as a great many players can't handle chained Ogg streams which result from the metadata updates."))
 
 
@@ -953,7 +973,7 @@ class FormatCodecOpusComplexity(FormatDropdown):
 
 
 class FormatCodecOpusBitRate(FormatSpin):
-    """Opus bit rate selection for stereo."""
+    """Opus bit rate selection."""
     
     def __init__(self, prev_object):
         dict_ = format_collate(prev_object)
@@ -1088,6 +1108,72 @@ class FormatCodecMPEG(FormatDropdown):
             tooltip)
 
 
+class FormatCodecWebMVorbisBitRate(FormatSpin):
+    """Vorbis bit rate selection."""
+    
+    def __init__(self, prev_object):
+        dict_ = format_collate(prev_object)
+        channels = 1 if dict_["mode"] == "mono" else 2
+        er = EncoderRange(VorbisTestEncoder())
+        sr = int(dict_["samplerate"])
+        bounds = er.bitrate_bounds(channels, sr)
+        FormatSpin.__init__(self, prev_object, _('Bitrate'), "bitrate",
+            (128000,) + bounds + (1, 10), 0, " bps", "FormatMetadataUTF8",
+            er.good_bitrates(channels, sr))
+
+
+class FormatCodecWebMVorbisSampleRate(FormatSpin):
+    """Vorbis sample rate selection."""
+    
+    def __init__(self, prev_object):
+        channels = 1 if format_collate(prev_object)["mode"] == "mono" else 2
+        er = EncoderRange(VorbisTestEncoder())
+        bounds = er.bounds(channels)["samplerate_bounds"]
+        FormatSpin.__init__(self, prev_object, _('Samplerate'), "samplerate",
+            (44100,) + bounds + (1, 10), 0, " Hz", "FormatCodecWebMVorbisBitRate",
+            er.good_samplerates(channels))
+
+
+class FormatCodecWebMVorbisMode(FormatDropdown):
+    """Vorbis mode selection."""
+    
+    def __init__(self, prev_object):
+        FormatDropdown.__init__(self, prev_object, _('Mode'), "mode", (
+            dict(display_text=_("Mono"), value="mono", chain="FormatCodecWebMVorbisSampleRate"),
+            dict(display_text=_("Stereo"), value="stereo", default=True, chain="FormatCodecWebMVorbisSampleRate")), 0)
+
+
+class FormatCodecWebMOpusBitRate(FormatSpin):
+    """Opus bit rate selection."""
+    
+    def __init__(self, prev_object):
+        dict_ = format_collate(prev_object)
+        channels = 1 if dict_["mode"] == "mono" else 2
+        bounds = (6 * channels, 256 * channels)
+        FormatSpin.__init__(self, prev_object, _('Bitrate'), "bitrate",
+            ((64, 96)[channels - 1],) + bounds + (1, 10), 0, " kbps", "FormatMetadataUTF8",
+            (256 * channels, 128 * channels, 64 * channels, 48 * channels, 32 * channels, 16 * channels))
+        self.scale = 1000
+
+
+class FormatCodecWebMOpusMode(FormatDropdown):
+    """Opus mode selection."""
+    
+    def __init__(self, prev_object):
+        FormatDropdown.__init__(self, prev_object, _('Mode'), "mode", (
+            dict(display_text=_("Mono"), value="mono", chain="FormatCodecWebMOpusBitRate"),
+            dict(display_text=_("Stereo"), value="stereo", default=True, chain="FormatCodecWebMOpusBitRate")), 0)
+
+
+class FormatCodecWebM(FormatDropdown):
+    """Audio only WebM codec selection."""
+
+    def __init__(self, prev_object):
+        FormatDropdown.__init__(self, prev_object, _('Codec'), "codec", (
+            dict(display_text=_('Opus'), value="opus", chain="FormatCodecWebMOpusMode", default=True),
+            dict(display_text=_('Vorbis'), value="vorbis", chain="FormatCodecWebMVorbisMode")), 0)
+
+
 class FormatFamily(FormatDropdown):
     """Gives choice of codec family/container format e.g. Xiph/Ogg or MPEG.
     
@@ -1097,6 +1183,7 @@ class FormatFamily(FormatDropdown):
     def __init__(self, prev_object):
         # TC: Codec family e.g. Xiph/Ogg, MPEG etc.
         FormatDropdown.__init__(self, prev_object, _('Family'), "family", (
+            dict(display_text=_('WebM'), value="webm", chain="FormatCodecWebM", shoutcast=False, sensitive=FGlobs.avenabled),
             # TC: Xiph.org Ogg container format.
             dict(display_text=_('Xiph/Ogg'), value="ogg", chain="FormatCodecXiphOgg", shoutcast=False),
             dict(display_text=_('MPEG'), value="mpeg", chain="FormatCodecMPEG", default=True)), 0,
@@ -1223,6 +1310,13 @@ class FormatControl(gtk.VBox):
             self.stop_encoder_rc()
             
     _cap_table = {
+            "webm":
+            {
+                "opus":
+                    {"shoutcast": False, "icecast": True, "recordable": True},
+                "vorbis":
+                    {"shoutcast": False, "icecast": True, "recordable": True},
+            },
             "ogg":
             {
                 "vorbis":
