@@ -1,6 +1,6 @@
 """Preliminary initialisation stuff."""
 
-#   Copyright (C) 2011 Stephen Fairchild (s-fairchild@users.sourceforge.net)
+#   Copyright (C) 2011, 2013 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation, either version 2 of the License, or
@@ -59,8 +59,9 @@ default = "default"
 
 # Regular expressions of files to copy when cloning a profile.
 config_files = ("config", "controls", "left_session", "main_session",
-    "main_session_files_played", "main_session_tracks", "playerdefaults",
-    "right_session", "s_data", "ports_.+_.+")
+    "main_session_files_played", "playerdefaults",
+    "right_session", "interlude_session", "effects[12]_session", "s_data",
+    "ports-.+-.+")
 
 
 class ArgumentParserError(Exception):
@@ -189,10 +190,14 @@ class ArgumentParserImplementation(object):
                 help=_("the voip mode at startup"))
         group.add_argument("-P", "--players", dest="players", nargs="+",
                 metavar="p",
-                help="the players to start among values {1,2}")
+                help="the players to start among values {1,2,3}")
         group.add_argument("-s", "--servers", dest="servers", nargs="+",
                 metavar="s",
                 help=_("attempt connection with the specified servers"))
+        group.add_argument("-k", "--kicksources", dest="kicksources", nargs="+",
+                metavar="k",
+                help=_("""kick sources on servers -- note that this will be
+                done before any server connection attempts are made"""))
         group.add_argument("-x", "--crossfader", dest="crossfader",
                 choices=("1", "2"),
                 help=_("position the crossfader for the specified player"))
